# frozen_string_literal: true

require "jekyll"
require "jekyll-coffeescript/version"
require "jekyll/converters/coffeescript"

module Jekyll
  module Coffeescript
  end
end
